<?php
/**
 * Scripts
 *
 * @package     MASHSU
 * @subpackage  Functions
 * @copyright   Copyright (c) 2015, René Hermenau
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/* Check if API Key is working properly
 * @since 1.0.0
 * @return string
 */

function mashsuCheckAPIkey(){
    global $mashsb_options;
    $appid = isset ($mashsb_options['google_app_id']) ? $appid = $mashsb_options['google_app_id'] : $appid = '';
    $shorturl = new mashsuGoogl($appid);
    
    $statusArr = $shorturl->checkApiKey('http://www.google.de');
    isset ($statusArr['error']['errors'][0]['reason']) ? $statusArr['error']['errors'][0]['reason'] : $statusArr['error']['errors'][0]['reason'] = '';
    
    if ( ! empty($mashsb_options['google_app_id']) && !empty ($statusArr['error']['errors'][0]['reason']) )
        return '<strong style="color:red;"> Notice: </strong>' . $statusArr['error']['errors'][0]['reason'];  
}

/*
 * Check if Plugin is enabled and returns shortened URL
 * 
 * @since 1.0.0
 * @param $url
 * @return string
 */
function mashsuGetShortURL($url) {
    global $mashsb_options;
    
    $expiration = isset($mashsb_options['mashsu_expiration']) ? $mashsb_options['mashsu_expiration'] : 31536000;
    
    //if (empty($url) || !isset($url))
        //return null;
    
    // if cache is disabled
    if (isset($mashsb_options['disable_cache']))
        delete_transient('mashsu_' . md5($url));

    // WP Shortlinks
    if ($mashsb_options['mashsu_methods'] === 'wpshortlinks')
        return wp_get_shortlink();

    // Get it from cache if possible
    $shortlink = get_transient('mashsu_' . md5($url));
    if (false === $shortlink) {

        // bitly
        if ($mashsb_options['mashsu_methods'] === 'bitly')
            $shortlink = mashsu_get_bitly_link($url);

        // Google shortlinks
        if ($mashsb_options['mashsu_methods'] === 'google')
            $shortlink = mashsu_get_google_link($url);
        
        set_transient('mashsu_' . md5($url), $shortlink, $expiration);
    }

    if (!empty($shortlink))
        return $shortlink;

    // default
    return $url;
}

/**
 * Get Google short url's like goo.gl/
 * 
 * @param string $url
 * @return string
 */
function mashsu_get_google_link($url){
    global $mashsb_options;
    
    $google_app_id = isset($mashsb_options['google_app_id']) ? $mashsb_options['google_app_id'] : '';
    
    // get result and fill cache
    if (!empty($google_app_id) && !empty($url) ) {
        $shorturl = new mashsuGoogl($google_app_id);
        $shorturlres = $shorturl->shorten($url, false);

        if (empty($shorturlres))
            return $url;

        unset($shorturl);
        return $shorturlres; 
    }
    return $url;
}

/*
 * Get shorturl generated by bitly
 * 
 * @return string
 */
function mashsu_get_bitly_link($url) {
    global $mashsb_options;

    $bitly_access_token = isset($mashsb_options['bitly_access_token']) ? $bitly_access_token = $mashsb_options['bitly_access_token'] : '';

    if (!empty($bitly_access_token) && !empty($url) && !is_null($url)){

            $params = array();
            $params['access_token'] = $bitly_access_token;
            $params['longUrl'] = $url;
            //$results = bitly_get('link/lookup', $params);
            $bitly = new mashshu_bitly();
            $results = $bitly->bitly_get( 'shorten', $params );

            if (!empty($results['data']['url'])){
                return $results['data']['url'];
            }
    }
    return $url;
}

/**
 * Returns a warning that bitly will be awful slow when Mashshare cache is disabled and add-on is used with Mashshare 2.5.2 and earlier
 */
function mashsu_return_bitly_warning(){
    if (version_compare(MASHSB_VERSION, '2.5.3', '<' ) )
            return __('<strong style="color:red;">Warning: </strong>Website will be awful slow when Mashshare cache is disabled and bitly support is enabled in this Mashshare version. You have the following options: <p>- Update to at least Mashshare 2.5.3<br>- Do not enable bitly support <br>- Never disable Mashshare cache','mashsu');

    return false;
}